export interface IProductModel {
    id: string;
    itemId: string;
    upc: string;
    name: string;
    price: number;
    quantity: number;
    qty: number;
    quantityOrder: number;
    image: string;
    unitOfMeasure: string;
    pricePer: number;
    promoDescription: string;
    description: string;
    salesRank: number;
    aisleId: string;
    departmentName: string;
    aisleName: string;
    shelfName: string;
    showStrikeThrough: Boolean;
    offerText: string;
    promoDescriptionVal: string;
    comment: string;
    comments: string;
    substitutionValue: string;
    substitutionPreference: string;
    promoType: string;
    promoTitle: string;
    basePrice: number;
    restrictedValue: number;
}

export interface ICouponModel {
    id: string;
    offerId: string;
    name: string;
    price: number;
    image: string;
    description: string;
    expiryDate: string;
    brand: string;
    category: string;
    offerPrice: string;
    status: string;
    offerType: string;
    refineBrand: string;
    refineDescription: string;
    refineOfferPrice: string;
    regularPrice: string;
    usageTypeTxt: string;
    usageType: string;
    offerPgmLabel: string;
    imageId: string;
    couponID: string;
    summary?: string;
}

export interface IDealModel {
    id: string;
    title: string;
    description: string;
    promo: string;
    image: string;
    expiryDate: string;
    brand: string;
    category: string;
    status: string;
}

export class DealModel implements IDealModel {
    id: string;
    title: string;
    description: string;
    promo: string;
    image: string;
    expiryDate: string;
    brand: string;
    category: string;
    status: string;

    constructor(data?: any) {
        Object.assign(this, data);
    };
}

export interface IDealUpdateModel {
    id: string;
    title: string;
    description: string;
    promo: string;
}

export class DealUpdateModel implements IDealUpdateModel {
    public id: string;
    public title: string;
    public description: string;
    public promo: string;

    constructor(data?: any) {
        Object.assign(this, data);
    };
}

export class CouponModel implements ICouponModel {
    public id: string;
    public offerId: string;
    public name: string;
    public price: number;
    public image: string;
    public description: string;
    public expiryDate: string;
    public updBtnText: string = 'Added';
    public updBtnMode: Boolean = true;
    public brand: string;
    public category: string;
    public offerPrice: string = '';
    public status: string;
    public deleted: boolean;
    public offerType: string;
    public offerTs: string;
    public endDate: string;
    public offerPgm: string;
    public refineBrand: string;
    public refineDescription: string;
    public refineOfferPrice: string;
    public regularPrice: string;
    public usageTypeTxt: string;
    public usageType: string;
    public offerPgmLabel: string;
    public imageId: string;
    public couponID: string;
    public summary?: string;

    constructor(data?: any) {
        Object.assign(this, data);
    };
}

export interface ICouponUpdateModel {
    id: string;
    price: number;
    offerId: string;
    offerPrice: string;
}

export class CouponUpdateModel implements ICouponUpdateModel {
    public id: string;
    public price: number;
    public offerId: string;
    public offerPrice: string;

    constructor(data?: any) {
        Object.assign(this, data);
    };
}

export class ProductModel implements IProductModel {
    public id: string;
    itemId: string;
    public upc: string;
    public name: string;
    public price: number;
    public quantity: number;
    public qty: number;
    public quantityOrder: number;
    public image: string;
    public unitOfMeasure: string;
    public pricePer: number;
    public promoDescription: string;
    public description: string;
    public salesRank: number;
    public aisleId: string;
    public departmentName: string;
    public aisleName: string;
    public shelfName: string;
    public updBtnText: string = 'Update';
    public updBtnMode: Boolean = true;
    public showStrikeThrough: Boolean;
    public offerText: string;
    public promoDescriptionVal: string;
    public comment: string;
    public comments: string;
    public substitutionValue: string;
    public substitutionPreference: string;
    public promoType: string;
    public promoTitle: string;
    public basePrice: number;
    public restrictedValue: number;

    constructor(data?: any) {
        Object.assign(this, data);
    };
}

export interface IProductUpdateModel {
    id: string;
    price: number;
    comment: string;
    substitutionValue: string;
    quantity: number;
}

export class ProductUpdateModel implements IProductUpdateModel {
    public id: string;
    public price: number;
    public comment: string;
    public substitutionValue: string;
    public quantity: number;

    constructor(data?: any) {
        Object.assign(this, data);
    };
}

export interface IFilter {
    id: string;
    label: any;
}

export class FilterModel implements IFilter {
    public id: string;
    public label: any;

    constructor(data?: any) {
        Object.assign(this, data);
    }
}

export interface ISortRule {
    field: string;
    direction: number;
    type: string;
    callback?: (a: ProductModel, s: SortModel) => void;
}

export interface ISort {
    field: string;
    rule: ISortRule[];
    label: any;
    selected?: Boolean;
}

export class SortModel implements ISort {
    public field: string;
    public label: any;
    public rule: ISortRule[];
    public selected?: Boolean;

    constructor(data?: any) {
        Object.assign(this, data);
    }
}
export class DepartmentModel implements IFilter {
    public id: string;
    public label: any;
    public aisle: string[];

    constructor(data?: any) {
        Object.assign(this, data);
    }
}

export class BrandModel implements IFilter {
    public id: string;
    public label: any;

    constructor(data?: any) {
        Object.assign(this, data);
    }
}

export interface LoaderState {
    show: boolean;
}

export interface ICarousel {
    type: String;
    behaviour: String;
    userRestrictions: String;
    dataSource: any;
    apiPostBody: any;
    actionButton: String;
}

export class CarouselModel implements ICarousel {
    public type: String;
    public behaviour: String;
    public userRestrictions: String;
    public dataSource: any;
    public title: String;
    public apiPostBody: any;
    public actionButton: String;
    public aisleName: String;

    constructor(data?: any) {
        Object.assign(this, data);
    }
}

export interface ICouponCarousel {
    carouselSource: String;
    carouselFilter: String;
    carouselOfferLimit: Number;
}

export class CouponCarouselModel implements ICouponCarousel {
    public carouselSource: String;
    public carouselFilter: String;
    public carouselOfferLimit: number;
    public errorMessage: string;
    public carouselTitle: String;
    public carouselLinkLabel: String;
    public carouselLinkPath: String;
    public upc: string;
    public includePageName: String = '';
    public odpOfferId: string;

    constructor(data?: any) {
        Object.assign(this, data);
    }
}

export interface IRewardsCarousel {
    errorMessage: string;
    title: string;
}

export class RewardsCarouselModel implements IRewardsCarousel {

    public errorMessage: string;
    public title: string;

    constructor(data?: any) {
        Object.assign(this, data);
    }
}

export interface IDealCarousel {
    // To be added
}

export class DealCarouselModel implements IDealCarousel {
    // To be added
    constructor(data?: any) {
        Object.assign(this, data);
    }
}

export interface IOfferDetail {
    offerId: string;
}

export class OfferDetail implements IOfferDetail {
    public offerId: string;

    constructor(data?: any) {
        Object.assign(this, data);
    };
}

export interface IRewardDetail {
    rewardId: string;
}

export class RewardDetail implements IRewardDetail {
    public rewardId: string;

    constructor(data?: any) {
        Object.assign(this, data);
    };
}

export interface IRewardModel {
    offerPrice: string;
    description: string;
    image: string;
    status: string;
    startDate: string;
    endDate: string;
    offerTs: string;
    usageType: string;
    offerPgm: string;
    purchaseInd: string;
    groceryRewardId: string;
    title: string;
    rewardsRequired: number;
    rewardsAvailable: number;
    generalDisclaimer: string;
    category: string;
    specialRank: number;
    displayStartDate: string;
    displayEndDate: string;
    detailPath: string;
}

export class RewardModel implements IRewardModel {
    offerPrice: string;
    description: string;
    image: string;
    status: string;
    startDate: string;
    endDate: string;
    offerTs: string;
    usageType: string;
    offerPgm: string;
    purchaseInd: string;
    groceryRewardId: string;
    title: string;
    rewardsRequired: number;
    rewardsAvailable: number;
    rewardsExpire: number;
    generalDisclaimer: string;
    category: string;
    specialRank: number;
    displayStartDate: string;
    displayEndDate: string;
    detailPath: string;

    constructor(data?: any) {
        Object.assign(this, data);
    }
}
