"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/**
 * Sort Service
 */
var core_1 = require("@angular/core");
// Services
var app_config_service_1 = require("wcax-core-angular/app.config.service");
var _ = require("lodash");
// Data model
var data_model_1 = require("../data.model");
var SortService = /** @class */ (function () {
    function SortService(appConfigService) {
        this.appConfigService = appConfigService;
        this.sorts = new Array();
        _.padStart('Hello TypeScript!', 20, ' ');
        this.rules = this.initRules();
        this.available = window['AB']['availableSorts'] || [];
        if (this.hasSort()) {
            this.generate();
        }
    }
    SortService.prototype.initRules = function () {
        var results;
        results = {
            'a-z': {
                field: 'name',
                rule: [{ field: 'name', direction: -1, type: 'string' }],
                label: 'Alphabetically'
            },
            'a-z-description': {
                field: 'description',
                rule: [{ field: 'description', direction: -1, type: 'string' }],
                label: 'Alphabetically'
            },
            'search-rank': {
                field: 'searchRank',
                rule: [
                    { field: 'searchRank', direction: -1, type: 'number' },
                    { field: 'name', direction: -1, type: 'string' }
                ],
                label: 'Search Ranking'
            },
            'most-popular': {
                field: 'salesRank',
                rule: [
                    { field: 'salesRank', direction: 1, type: 'number' },
                    { field: 'name', direction: -1, type: 'string' }
                ],
                label: 'Most Popular'
            },
            'price-low-high': {
                field: 'price',
                rule: [
                    { field: 'price', direction: -1, type: 'number' },
                    { field: 'name', direction: -1, type: 'string' }
                ],
                label: 'Price - Low to High'
            },
            'purchase-history': {
                field: 'purchaseRank',
                rule: [
                    { field: 'purchaseRank', direction: -1, type: 'string' }
                ],
                label: 'Purchase History'
            },
            'new-offers': {
                field: 'arrivalRank',
                rule: [
                    { field: 'arrivalRank', direction: 1, type: 'string' }
                ],
                label: 'New Offers'
            },
            'about-to-expire': {
                field: 'expiryRank',
                rule: [
                    { field: 'expiryRank', direction: 1, type: 'string' }
                ],
                label: 'About to Expire'
            },
            'category': {
                field: 'categoryId',
                rule: [
                    { field: 'categoryId', direction: 1, type: 'string' }
                ],
                label: 'Category'
            },
            'expiry-date': {
                field: 'endDate',
                rule: [
                    { field: 'endDate', direction: 1, type: 'string' }
                ],
                label: 'Expiry Date'
            },
            'added-date': {
                field: 'addedDate',
                rule: [
                    { field: 'addedDate', direction: 1, type: 'string' }
                ],
                label: 'Added Date'
            },
            'reward-card-specials': {
                field: 'promoDescription',
                rule: [
                    {
                        field: 'promoDescription',
                        direction: -1,
                        type: 'custom',
                        callback: function (tempA, sort) {
                            if (this.isPromoMatch(tempA[sort.field])) {
                                return 'AAA';
                            }
                            else {
                                return 'ZZZ';
                            }
                        }
                    },
                    { field: 'name', direction: -1, type: 'string' }
                ],
                label: this.appConfigService.getPromoDescription()
            },
            aisles: {
                // dummy, needs to be here for now for backwards compatibility
                field: 'groupByTemplate',
                rule: [],
                label: 'Aisles'
            },
            aisles_departmentName: {
                field: 'departmentName',
                rule: [
                    { field: 'departmentName', direction: -1, type: 'string' },
                    { field: 'name', direction: -1, type: 'string' }
                ],
                label: 'Aisles'
            },
            aisles_aisleName: {
                field: 'aisleName',
                rule: [
                    { field: 'aisleName', direction: -1, type: 'string' },
                    { field: 'name', direction: -1, type: 'string' }
                ],
                label: 'Aisles'
            },
            aisles_shelfName: {
                field: 'shelfName',
                rule: [
                    { field: 'shelfName', direction: -1, type: 'string' },
                    { field: 'name', direction: -1, type: 'string' }
                ],
                label: 'Aisles'
            },
            'bloomreach-top-sellers': {
                field: 'salesRank+asc',
                rule: null,
                label: 'Top sellers'
            },
            'bloomreach-price-low-high': {
                field: 'price+asc',
                rule: null,
                label: 'Price low to high'
            },
            'bloomreach-best-match': {
                field: '',
                rule: null,
                label: 'Best Match'
            },
            'bloomreach-club-card': {
                field: 'promoType+asc',
                rule: null,
                label: this.appConfigService.getPromoDescription()
            },
            aisles_coupons: {
                // dummy, needs to be here for now for backwards compatibility
                field: 'purchaseInd',
                rule: [{ field: 'purchaseInd', direction: -1, type: 'string' }],
                label: 'Type of Coupons'
            }
        };
        return results;
    };
    SortService.prototype.isPromoMatch = function (label) {
        var promoRules = this.appConfigService.getPromorulesArray();
        if (!promoRules || promoRules.length === 0) {
            return false;
        }
        var found = false;
        promoRules.forEach(function (promoRule) {
            if (label && label.length > 0) {
                if (label.match(promoRule['rule'])) {
                    found = true;
                }
            }
        });
        return found;
    };
    SortService.prototype.setAvailableSort = function (sort) {
        this.available = sort;
    };
    SortService.prototype.getDefaultSort = function () {
        if (this.default != undefined)
            return this.default;
        if (this.available.filter(function (rule) { return rule === 'a-z'; }).length > 0)
            this.default = this.getSortByName('a-z');
        else
            this.default = (this.available[0] != undefined) ? this.getSortByName(this.available[0]) : this.getSortByName('a-z');
        return this.default;
    };
    SortService.prototype.getDefaultSortForConfigurableSort = function (defaultRule) {
        if (this.available.filter(function (rule) { return rule === defaultRule; }).length > 0)
            this.default = this.getSortByName(defaultRule);
        else
            this.default = (this.available[0] != undefined) ? this.getSortByName(this.available[0]) : this.getSortByName(defaultRule);
        return this.default;
    };
    SortService.prototype.hasSort = function () {
        return !!this.available.length;
    };
    SortService.prototype.getSortByName = function (name) {
        return this.rules[name];
    };
    SortService.prototype.getSorts = function () {
        return this.sorts;
    };
    SortService.prototype.sort = function (sort, data) {
        var _this = this;
        var sortByCriteria = sort.rule.map(function (rule) {
            return function (a) {
                var tempA = Object.assign({}, a);
                if (rule.type === 'string') {
                    if (tempA && tempA[rule.field]) {
                        tempA[rule.field] = tempA[rule.field].toString().toLowerCase();
                    }
                }
                if (rule.type === 'number') {
                    tempA[rule.field] = parseFloat(tempA[rule.field]);
                }
                if (rule.type === 'custom') {
                    return rule.callback.call(_this, tempA, sort);
                }
                return tempA[rule.field];
            };
        });
        var sortByDirection = sort.rule.map(function (rule) {
            if (rule.direction === 1) {
                return 'asc';
            }
            else {
                return 'desc';
            }
        });
        return _.sortBy(data, sortByCriteria, sortByDirection);
    };
    SortService.prototype.couponsSort = function (sort, data) {
        var _this = this;
        var sortByCriteria = sort.rule.map(function (rule) {
            return function (a) {
                var tempA = Object.assign({}, a);
                if (rule.type === 'string') {
                    if (tempA && tempA[rule.field]) {
                        tempA[rule.field] = tempA[rule.field].toString().toLowerCase();
                    }
                }
                if (rule.type === 'number') {
                    tempA[rule.field] = parseFloat(tempA[rule.field]);
                }
                if (rule.type === 'custom') {
                    return rule.callback.call(_this, tempA, sort);
                }
                return tempA[rule.field];
            };
        });
        var sortByDirection = sort.rule.map(function (rule) {
            if (rule.direction === 1) {
                return 'asc';
            }
            else {
                return 'desc';
            }
        });
        return _.sortBy(data, sortByCriteria, sortByDirection);
    };
    SortService.prototype.generate = function () {
        var _this = this;
        if (this.available.length === 0) {
            return;
        }
        this.available.forEach(function (type, index) {
            var rule = _this.rules[type];
            if (!rule) {
                return;
            }
            /* overwrite with custom group by rule based on headerType setting */
            if (rule.field === 'groupByTemplate') {
                var groupByRuleKey = 'aisles' + '_' + window['AB']['headerType'];
                rule.rule = _this.rules[groupByRuleKey].rule;
            }
            _this.sorts.push(new data_model_1.SortModel(rule));
            if (_this.default === undefined && type === window['AB']['defaultSort']) {
                _this.default = rule;
            }
        });
    };
    SortService = tslib_1.__decorate([
        core_1.Injectable(),
        tslib_1.__metadata("design:paramtypes", [app_config_service_1.AppConfigService])
    ], SortService);
    return SortService;
}());
exports.SortService = SortService;
//# sourceMappingURL=sort.service.js.map