import { Component, Injectable, Input, OnInit, ElementRef, AfterViewInit } from "@angular/core";

// Services
import { ModalService } from "./modal.service";
import { ClipService } from "wcax-core-angular/clip.service";

// Data model
import { RewardModel } from "../data.model";

// jQuery
declare var $: any;

function _window(): any {
    return window;
}

@Component({
    selector: "child-modal",
    templateUrl: "./modal.component.html"
})
@Injectable()
export class ChildModalComponent implements OnInit, AfterViewInit {
    @Input() type;
    @Input() reward;
    @Input() cancelRedemptionButton;
    public modal: any = {
        title: "",
        titleBorder: false,
        id: "",
        modalClass: "",
        isRewardsSelected: false,
        isRewardsRedemption: false,
      //  isBoxtop: false,
        isServiceDetails: false,
        type: '',
        actionButton: '',
        reward: {},
        rewardId: '',
        displayRedemptionButton: true,
        titleId: "",
        describedId: ""
    };
    public rewardsSelected: RewardModel[] = [];

    public constructor(
        public elementRef: ElementRef,
        private _modalService: ModalService,
        private couponClipFn: ClipService
    ) {}

    public ngOnInit() {
        this.modal.type = this.type;
        this.modal.reward = this.reward;
        if(this.cancelRedemptionButton==true) this.modal.displayRedemptionButton = false;
        if (this.modal.type == "rewards-redemption") {
            //this.modal.title=`${ this.modal.reward.rewardsRequired } ${this.modal.reward.rewardsRequired == 1 ? "Reward" : "Rewards"} will be used for:`;
            this.modal.title = 'Confirm';
            this.modal.id ="rewards-redemption-confirmation-modal-"+this.modal.reward.groceryRewardId;
            this.modal.actionButton = `Use ${this.modal.reward.rewardsRequired} ${this.modal.reward.rewardsRequired == 1 ? "Reward" : "Rewards"}`;
            this.modal.titleBorder = false;
            this.modal.isRewardsRedemption = true;
            this.modal.titleId = "rewards-redemption-title-id"+this.modal.reward.groceryRewardId;
            this.modal.describedId = "rewards-redemption-described-id"+this.modal.reward.groceryRewardId;
            this.modal.disableConfirmButtonID = '';
        }
    }

    public ngAfterViewInit() {
        // window['AB']['ARIA'].rewardsModalFocus(this.modal.id);
        let modalId = this.modal.id;
        let modalTitleId = this.modal.titleId;
        let check = false;
        let focusId = null;
        let rewards = [];
        let rewardIndex = 0;

        //rewards redemption modals
        if (this.modal.type == "rewards-redemption") {
            //on shown rewards redemption modal
            $("#" + this.modal.id).on('shown.bs.modal', function () {
                $("#" + modalId).attr('aria-hidden', 'false');
                //focus to modal header
                $("#" + modalTitleId).focus();
                //keep focus in modal when tabbing X icon
                $('.modal-refocus').on('keydown', function (e) {
                    //tab key is hit and X icon is focused
                    if ((e.which == 9) && $("this:focus")) {
                        //tab back
                        if (e.shiftKey == true) {
                            e.preventDefault();
                            $('.modal-refocus1').focus();
                        }
                        else if (e.shiftKey == false) {
                            e.preventDefault();
                            $('.modal-heading').focus();
                        }
                    }
                    console.log('modal-refocu key down');
                });
                //keep focus in modal when tabbing confirm btn
                $('.modal-refocus1').on('keydown', function (e) {
                    //tab key is hit and confirm button is focused
                    if ((e.which == 9) && $("this:focus")) {
                       if (e.shiftKey == false) {
                            e.preventDefault();
                            $('.modal-close').focus();
                        }
                    }
                    console.log('modal-refocus1 key down');
                });

                //If cancel or x is hit, clear rewardFocus from localStorage//
                $('.modal-cancel, .modal-x').click(function() {
                    localStorage.setItem('rewardFocus', '');
                })

                //Get next focusable element//
                check = false;
                focusId = null;
                rewards = [];
                rewardIndex = 0;
                $('.reward-use-btn').each(function() {
                    rewards[rewardIndex] = $(this).data('focus');
                    rewardIndex++;

                    if(check == true && !focusId) {
                        focusId = $(this).data('focus');
                        localStorage.setItem("rewardFocus", focusId);
                    }

                    if($(this).data('focus') == modalTitleId) {
                        check = true;
                    }
                })

                if(!focusId) {
                    localStorage.setItem("rewardFocus", rewards[rewardIndex - 2]);
                }
            });
            $("#" + this.modal.id).on('hidden.bs.modal', function(){
                $("#" + modalId).attr('aria-hidden', 'true');
            });
        }
    }

    public clipReward() {
        this.modal.reward.isConfirmModalButtonDisabled = true;
        this.couponClipFn.clipReward(this.modal.reward, this.updateStatistics);
    }

    private updateStatistics() {
        // update analytics data layer
        window['AB']['DATALAYER'].pushEvent({ name: 'coupon_clipped' });
        if (localStorage.getItem('abCoupons')) {
            let allCoupons = JSON.parse(localStorage.getItem('abCoupons'));
            for (let offerId in allCoupons.offers) {
                let coupon = allCoupons.offers[offerId];
                if (coupon.offerTs == this.reward.offerTs) {
                    let couponInfo = {
                        brand: coupon.brand,
                        offerType: coupon.offerPgm,
                        offerId: coupon.offerId,
                        offerPrice: coupon.offerPrice,
                        carouselSection: this.reward.rewardsRequired + " Rewards"
                    };
                    window['AB']['DATALAYER'].clipCoupon(couponInfo);
                }
            }
        }
    }

    //Not used but have to be declared because they use the same html template
    public getSelectedRewards(){
         if (this._isRegistered()&&this.modal.isRewardsRedemption) {
            //add class to active reward offer for ADA focus
            var activeId = this.modal.id;
            $('#'+ activeId).closest('.reward-grid-itme').addClass('activeRewardsModal');

            this._modalService
            .getSelectedRewardsOffers()
            .subscribe(response => {
                this.rewardsSelected = response;
            });
        }
    }

    private _isRegistered(): boolean {
        return (window['AB']['COMMON'].sessionNotExpired() && window['AB']['COMMON'].authorizeJ4U());
    }
}

