/**
* Angular App Modules.
*
* @file Main Angular's application properties.
*/
import { NgModule, ApplicationRef, Injectable, Inject, ComponentFactoryResolver, Type } from '@angular/core';
import { HttpClientModule, HttpClient } from '@angular/common/http';
import { BrowserModule } from '@angular/platform-browser';
import { FormsModule } from '@angular/forms';
import { CoreModule } from 'wcax-core-angular/core.module'
/**
* Main Components.
*
* @description Components that should be boostraped directly in AEM page(s).
*/

import { SearchComponent } from "./search/search.component";
import { ModalComponent } from './modal/modal.component';


/**
* Children Components.
*
* @description Components that extends Main Components functionality and are not bootstrapped individually.
*/
import { SortComponent } from './sort/sort.component';
import { LoaderComponent } from './loading-spinner/loading-spinner.component';
import { ChildModalComponent } from "./modal/child-modal.component";

/**
* Main & Children components Services.
*
* @description Services that are used across Angular application.
*/
import { SortService } from "./sort/sort.service";
import { LoaderService } from './loading-spinner/loading-spinner.service';
import { ModalService } from './modal/modal.service';



// Angular's NgModule
@NgModule({
    declarations: [
        SortComponent,
        LoaderComponent,
        ChildModalComponent,
        SearchComponent,
        ModalComponent
    ],
    imports: [
        BrowserModule,
        HttpClientModule,
        FormsModule,
        CoreModule
    ],
    providers: [
        SortService,
        LoaderService,
        ModalService
    ],
    exports: [
        SearchComponent,
        ModalComponent,
        LoaderComponent,
        SortComponent,
        ChildModalComponent
    ]
})
@Injectable()
export class SharedModule {}
