import {
    Component,
    Output,
    EventEmitter,
    Input,
    OnChanges,
    SimpleChanges,
    AfterViewInit,
    ViewChild
} from '@angular/core';
import {ElementRef, Renderer2} from '@angular/core';

// Data Model
import {SortModel} from '../data.model';

declare var $: any;

@Component({
    selector: 'sort-by',
    templateUrl: './sort.component.html'
})


export class SortComponent implements OnChanges, AfterViewInit {
    @Input() sortRules: SortModel[];
    @Input() activeSortRule: SortModel;
    @Output() activeSortRuleEmitter: EventEmitter<SortModel> = new EventEmitter<SortModel>();
    @ViewChild('sortId') el: ElementRef;

    public arriaExpanded: Boolean = false;
    public selectedSortRuleIndex: Number;
    public defaultSorted: Boolean = false;

    constructor(private rd: Renderer2) {

    }

    public doSortEmitter(activeSortRule: SortModel) {
        this.activeSortRule = activeSortRule;
        this.activeSortRuleEmitter.emit(this.activeSortRule);
    }

    /**
     * Triggered on properties changes - Search and update new active sort rule index
     *
     * @param {SimpleChanges} changes properties that has been changed
     */
    public ngOnChanges(changes: SimpleChanges): void {
        if (changes.activeSortRule)
            this.sortRules.forEach(
                (sort, i) => {
                    if (sort.field === this.activeSortRule.field) {
                        this.selectedSortRuleIndex = i;
                        sort.selected = true;
                        if (this.defaultSorted) window['AB']['DATALAYER'].sortBy(sort.label);
                        this.defaultSorted = true;
                    } else
                        sort.selected = null;
                }
            );
    }

    /**
     * Call Accessibility ARIA methods
     */
    public ngAfterViewInit(): void {
        this.sortByComponent();
        /* $(this.el.nativeElement).focus(); */
        this.el.nativeElement.style.background = "white";
        this.el.nativeElement.style.border = "0px solid";

        if (this.el.nativeElement == undefined) {
            console.log("sortID NO detected")
        } else {
            console.log("sortID YES detected")
        }
    }

    /* Sort by, Angular dropdown component ARIA , Taken from ARIA.JS*/
    public sortByComponent = function () {
        var sortBy = $(".dropdown-sort-by.dropdown");
        var sortByButton = sortBy.find('#sortByID');

        $(".sort-by-text").focusout(function () {
            $(this).css('outline', 'none')
        });

        /* aria-expanded removed when dropdown list is hidden + focus changing*/
        sortBy.on("hidden.bs.dropdown", function (e) {
            sortByButton.removeAttr('aria-expanded');
            e.preventDefault();
            setTimeout(function () {
                $('body .sort-by-wrapper button#sortByID').focus();
            }, 300);
        });

        // to add the showPromo class for filters in mobile view
        if ($('div.cfh-banner.cfh-banner__search').length > 0) {
            $('#filterMV').addClass('showPromo')
        }
        $(document).not('.squaredThree').on('click', 'label', function (e) {
            $(this).css('outline', 'none')
        });
        $('.label-more').on('click', function (e) {
            $(this).prev().children(':eq(5)').children('label').css('outline', 'none') //.css('outline','none')
            // $('#searchFilterBy' + id + ' .filter-wrapper div:nth-child(6) input').parent().css('outline','none')
        });
    };

}
